@@ -26,7 +26,8 @@ typedef struct
     unsigned int rate;
     int channels;
     unsigned buffer_time;
-    unsigned periods;
+    int periods;
+    int frame_bytes;
 
     snd_pcm_t *fd;
     char **metadata;
